@@ -71,7 +71,7 @@ int32_t SPVM__Sys__Socket__inet_aton(SPVM_ENV* env, SPVM_VALUE* stack) {
   void* obj_cp = stack[0].oval;
   
   if (!obj_cp) {
-    return env->die(env, stack, "$cp must be defined.", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "The address string $cp must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   const char* cp = env->get_chars(env, stack, obj_cp);
@@ -79,7 +79,7 @@ int32_t SPVM__Sys__Socket__inet_aton(SPVM_ENV* env, SPVM_VALUE* stack) {
   void* obj_inp = stack[1].oval;
   
   if (!obj_inp) {
-    return env->die(env, stack, "$inp must be defined.", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "The address data structure $inp must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   struct in_addr* st_in_addr = env->get_pointer(env, stack, obj_inp);
@@ -95,7 +95,7 @@ int32_t SPVM__Sys__Socket__inet_aton(SPVM_ENV* env, SPVM_VALUE* stack) {
     return InvalidNetworkAddress;
   }
   else if (status == -1) {
-    env->die(env, stack, "[System Error]inet_aton failed: %s.", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]inet_aton() failed:%s.", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -109,7 +109,7 @@ int32_t SPVM__Sys__Socket__inet_ntoa(SPVM_ENV* env, SPVM_VALUE* stack) {
   void* obj_in = stack[0].oval;
   
   if (!obj_in) {
-    return env->die(env, stack, "$in address must be defined.", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "The address data structure $in must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   struct in_addr* in = env->get_pointer(env, stack, obj_in);
@@ -117,7 +117,7 @@ int32_t SPVM__Sys__Socket__inet_ntoa(SPVM_ENV* env, SPVM_VALUE* stack) {
   char* output_address = inet_ntoa(*in);
   
   if (!output_address) {
-    env->die(env, stack, "[System Error]inet_ntoa failed: %s.", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]inet_ntoa() failed:%s.", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -150,13 +150,13 @@ int32_t SPVM__Sys__Socket__inet_pton(SPVM_ENV* env, SPVM_VALUE* stack) {
   int32_t af = stack[0].ival;
   
   if (!(af == AF_INET || af == AF_INET6)) {
-    return env->die(env, stack, "$af must be AF_INET or AF_INET6.", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "The address family $af must be AF_INET or AF_INET6.", __func__, FILE_NAME, __LINE__);
   }
   
   void* obj_src = stack[1].oval;
   
   if (!obj_src) {
-    return env->die(env, stack, "$src must be defined.", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "The address string $src must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   const char* src = env->get_chars(env, stack, obj_src);
@@ -164,21 +164,21 @@ int32_t SPVM__Sys__Socket__inet_pton(SPVM_ENV* env, SPVM_VALUE* stack) {
   void* obj_dst = stack[2].oval;
   
   if (!obj_dst) {
-    return env->die(env, stack, "$dst must be defined.", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "The address data structure $dst must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   if (af == AF_INET) {
     if (!env->is_type_by_name(env, stack, obj_dst, "Sys::Socket::In_addr", 0)) {
-      return env->die(env, stack, "$dst must be the Sys::Socket::In_addr class.", __func__, FILE_NAME, __LINE__);
+      return env->die(env, stack, "The address data structure $dst must be the Sys::Socket::In_addr class.", __func__, FILE_NAME, __LINE__);
     }
   }
   else if (af == AF_INET6) {
     if (!env->is_type_by_name(env, stack, obj_dst, "Sys::Socket::In6_addr", 0)) {
-      return env->die(env, stack, "$dst must be the Sys::Socket::In6_addr class.", __func__, FILE_NAME, __LINE__);
+      return env->die(env, stack, "The address data structure $dst must be the Sys::Socket::In6_addr class.", __func__, FILE_NAME, __LINE__);
     }
   }
   else {
-    return env->die(env, stack, "The type of $dst is invalid.", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "The type of The address data structure $dst is invalid.", __func__, FILE_NAME, __LINE__);
   }
   
   void* dst = env->get_pointer(env, stack, obj_dst);
@@ -190,7 +190,7 @@ int32_t SPVM__Sys__Socket__inet_pton(SPVM_ENV* env, SPVM_VALUE* stack) {
     return InvalidNetworkAddress;
   }
   else if (status == -1) {
-    env->die(env, stack, "[System Error]inet_pton failed: %s.", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]inet_pton() failed:%s.", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -205,20 +205,20 @@ int32_t SPVM__Sys__Socket__inet_ntop(SPVM_ENV* env, SPVM_VALUE* stack) {
   int32_t af = stack[0].ival;
   
   if (!(af == AF_INET || af == AF_INET6)) {
-    return env->die(env, stack, "$af must be AF_INET or AF_INET6.", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "The address family $af must be AF_INET or AF_INET6.", __func__, FILE_NAME, __LINE__);
   }
   
   // The input address
   void* obj_src = stack[1].oval;
   if (!obj_src) {
-    return env->die(env, stack, "$src must be defined.", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "The address data structure $src must be defined.", __func__, FILE_NAME, __LINE__);
   }
   void* src = env->get_pointer(env, stack, obj_src);
   
   // The output address
   void* obj_dst = stack[2].oval;
   if (!obj_dst) {
-    return env->die(env, stack, "$dst must be defined.", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "The address string $dst must be defined.", __func__, FILE_NAME, __LINE__);
   }
   char* dst = (char*)env->get_chars(env, stack, obj_dst);
   
@@ -228,7 +228,7 @@ int32_t SPVM__Sys__Socket__inet_ntop(SPVM_ENV* env, SPVM_VALUE* stack) {
   const char* dst_ret = inet_ntop(af, src, dst, size);
   
   if (!dst_ret) {
-    env->die(env, stack, "[System Error]inet_ntop failed: %s.", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]inet_ntop() failed:%s.", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -248,7 +248,7 @@ int32_t SPVM__Sys__Socket__socket(SPVM_ENV* env, SPVM_VALUE* stack) {
   int32_t sockfd = socket(domain, type, protocol);
   
   if (sockfd == -1) {
-    env->die(env, stack, "[System Error]socket failed: %s.", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]socket() failed:%s.", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -264,7 +264,7 @@ int32_t SPVM__Sys__Socket__connect(SPVM_ENV* env, SPVM_VALUE* stack) {
   void* obj_addr = stack[1].oval;
   
   if (!obj_addr) {
-    return env->die(env, stack, "$addr must be defined.", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "The socket address $addr must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   const struct sockaddr* addr = env->get_pointer(env, stack, obj_addr);
@@ -274,7 +274,7 @@ int32_t SPVM__Sys__Socket__connect(SPVM_ENV* env, SPVM_VALUE* stack) {
   int32_t status = connect(sockfd, addr, addrlen);
   
   if (status == -1) {
-    env->die(env, stack, "[System Error]connect failed: %s.", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]connect() failed:%s.", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -290,7 +290,7 @@ int32_t SPVM__Sys__Socket__bind(SPVM_ENV* env, SPVM_VALUE* stack) {
   void* obj_addr = stack[1].oval;
   
   if (!obj_addr) {
-    return env->die(env, stack, "$addr must be defined.", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "The socket address $addr must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   const struct sockaddr* addr = env->get_pointer(env, stack, obj_addr);
@@ -300,7 +300,7 @@ int32_t SPVM__Sys__Socket__bind(SPVM_ENV* env, SPVM_VALUE* stack) {
   int32_t status = bind(sockfd, addr, addrlen);
   
   if (status == -1) {
-    env->die(env, stack, "[System Error]bind failed: %s.", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]bind() failed:%s.", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -316,7 +316,7 @@ int32_t SPVM__Sys__Socket__accept(SPVM_ENV* env, SPVM_VALUE* stack) {
   void* obj_addr = stack[1].oval;
   
   if (!obj_addr) {
-    return env->die(env, stack, "$addr must be defined.", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "The socket address $addr must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   struct sockaddr* addr = env->get_pointer(env, stack, obj_addr);
@@ -328,7 +328,7 @@ int32_t SPVM__Sys__Socket__accept(SPVM_ENV* env, SPVM_VALUE* stack) {
   int32_t status = accept(sockfd, addr, &sl_addrlen);
   
   if (status == -1) {
-    env->die(env, stack, "[System Error]accept failed: %s.", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]accept() failed:%s.", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -348,7 +348,7 @@ int32_t SPVM__Sys__Socket__listen(SPVM_ENV* env, SPVM_VALUE* stack) {
   int32_t status = listen(sockfd, backlog);
   
   if (status == -1) {
-    env->die(env, stack, "[System Error]listen failed: %s.", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]listen() failed:%s.", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -366,7 +366,7 @@ int32_t SPVM__Sys__Socket__shutdown(SPVM_ENV* env, SPVM_VALUE* stack) {
   int32_t status = shutdown(sockfd, how);
   
   if (status == -1) {
-    env->die(env, stack, "[System Error]shutdown failed: %s.", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]shutdown() failed:%s.", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -377,7 +377,7 @@ int32_t SPVM__Sys__Socket__shutdown(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__Sys__Socket__closesocket(SPVM_ENV* env, SPVM_VALUE* stack) {
 #if !defined(_WIN32)
-  env->die(env, stack, "[Not Supported]closesocket is not supported in this system(!defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "Sys::Socket#closesocket method is not supported in this system(!defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #else
   int32_t s = stack[0].ival;
@@ -385,7 +385,7 @@ int32_t SPVM__Sys__Socket__closesocket(SPVM_ENV* env, SPVM_VALUE* stack) {
   int32_t status = closesocket(s);
   
   if (!(status == 0)) {
-    env->die(env, stack, "[System Error]close failed: %s.", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]close() failed:%s.", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -402,7 +402,7 @@ int32_t SPVM__Sys__Socket__recv(SPVM_ENV* env, SPVM_VALUE* stack) {
   void* obj_buf = stack[1].oval;
   
   if (!obj_buf) {
-    return env->die(env, stack, "$buf must be defined.", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "The buffer $buf must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   char* buf = (char*)env->get_chars(env, stack, obj_buf);
@@ -414,13 +414,13 @@ int32_t SPVM__Sys__Socket__recv(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   int32_t buf_offset = stack[4].ival;
   if (!(len <= buf_length - buf_offset)) {
-    return env->die(env, stack, "$len must be less than the length of $buf - $buf_offset.", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "The data length $len must be less than the length of the buffer $buf minus the buffer offset $buf_offset.", __func__, FILE_NAME, __LINE__);
   }
   
   int32_t bytes_length = recv(sockfd, buf + buf_offset, len, flags);
   
   if (bytes_length == -1) {
-    env->die(env, stack, "[System Error]recv failed: %s.", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]recv() failed:%s.", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -436,7 +436,7 @@ int32_t SPVM__Sys__Socket__send(SPVM_ENV* env, SPVM_VALUE* stack) {
   void* obj_buf = stack[1].oval;
   
   if (!obj_buf) {
-    return env->die(env, stack, "$buf must be defined.", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "The buffer $buf must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   const char* buf = env->get_chars(env, stack, obj_buf);
@@ -448,13 +448,13 @@ int32_t SPVM__Sys__Socket__send(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   int32_t buf_offset = stack[4].ival;
   if (!(len <= buf_length - buf_offset)) {
-    return env->die(env, stack, "$len must be less than the length of $buf - $buf_offset.", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "The data length $len must be less than the length of the buffer $buf minus the buffer offset $buf_offset.", __func__, FILE_NAME, __LINE__);
   }
   
   int32_t bytes_length = send(sockfd, buf + buf_offset, len, flags);
   
   if (bytes_length == -1) {
-    env->die(env, stack, "[System Error]send failed: %s.", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]send() failed:%s.", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -470,7 +470,7 @@ int32_t SPVM__Sys__Socket__sendto(SPVM_ENV* env, SPVM_VALUE* stack) {
   void* obj_buf = stack[1].oval;
   
   if (!obj_buf) {
-    return env->die(env, stack, "$buf must be defined.", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "The buffer $buf must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   const char* buf = env->get_chars(env, stack, obj_buf);
@@ -483,7 +483,7 @@ int32_t SPVM__Sys__Socket__sendto(SPVM_ENV* env, SPVM_VALUE* stack) {
   void* obj_addr = stack[4].oval;
   
   if (!obj_addr) {
-    return env->die(env, stack, "$addr must be defined.", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "The socket address $addr must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   const struct sockaddr* addr = env->get_pointer(env, stack, obj_addr);
@@ -492,13 +492,13 @@ int32_t SPVM__Sys__Socket__sendto(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   int32_t buf_offset = stack[6].ival;
   if (!(len <= buf_length - buf_offset)) {
-    return env->die(env, stack, "$len must be less than the length of $buf - $buf_offset.", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "The data length $len must be less than the length of the buffer $buf minus the buffer offset $buf_offset.", __func__, FILE_NAME, __LINE__);
   }
   
   int32_t bytes_length = sendto(sockfd, buf + buf_offset, len, flags, addr, addrlen);
   
   if (bytes_length == -1) {
-    env->die(env, stack, "[System Error]sendto failed: %s.", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]sendto() failed:%s.", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -514,7 +514,7 @@ int32_t SPVM__Sys__Socket__getpeername(SPVM_ENV* env, SPVM_VALUE* stack) {
   void* obj_addr = stack[1].oval;
   
   if (!obj_addr) {
-    return env->die(env, stack, "$addr must be defined.", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "The socket address $addr must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   struct sockaddr* addr = env->get_pointer(env, stack, obj_addr);
@@ -526,7 +526,7 @@ int32_t SPVM__Sys__Socket__getpeername(SPVM_ENV* env, SPVM_VALUE* stack) {
   int32_t status = getpeername(sockfd, addr, &sl_addrlen);
   
   if (status == -1) {
-    env->die(env, stack, "[System Error]getpeername failed: %s.", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]getpeername() failed:%s.", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -544,7 +544,7 @@ int32_t SPVM__Sys__Socket__getsockname(SPVM_ENV* env, SPVM_VALUE* stack) {
   void* obj_addr = stack[1].oval;
   
   if (!obj_addr) {
-    return env->die(env, stack, "$addr must be defined.", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "The socket address $addr must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   struct sockaddr* addr = env->get_pointer(env, stack, obj_addr);
@@ -556,7 +556,7 @@ int32_t SPVM__Sys__Socket__getsockname(SPVM_ENV* env, SPVM_VALUE* stack) {
   int32_t status = getsockname(sockfd, addr, &sl_addrlen);
   
   if (status == -1) {
-    env->die(env, stack, "[System Error]getsockname failed: %s.", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]getsockname() failed:%s.", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -578,24 +578,24 @@ int32_t SPVM__Sys__Socket__getsockopt(SPVM_ENV* env, SPVM_VALUE* stack) {
   void* obj_optval = stack[3].oval;
   char* optval = NULL;
   if (!obj_optval) {
-    return env->die(env, stack, "$optval must be defined.", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "The option value $optval must be defined.", __func__, FILE_NAME, __LINE__);
   }
   optval = (char*)env->get_chars(env, stack, obj_optval);
   int32_t optval_length = env->length(env, stack, obj_optval);
   
   int32_t* optlen_ref = stack[4].iref;
   if (!(*optlen_ref >= 0)) {
-    env->die(env, stack, "The referred value of $optlen_ref must be greater than or equal to 0.", __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "The length stored at index 0 of $optlen_ref must be greater than or equal to 0.", __func__, FILE_NAME, __LINE__);
   }
   if (!(*optlen_ref <= optval_length)) {
-    env->die(env, stack, "The referred value of $optlen_ref must be less than or equal to the length of $optval.", __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "The length stored at index 0 of $optlen_ref must be less than or equal to the length of the option value $optval.", __func__, FILE_NAME, __LINE__);
   }
   
   socklen_t socklen_t_optlen = *optlen_ref;
   int32_t status = getsockopt(sockfd, level, optname, optval, &socklen_t_optlen);
   
   if (status == -1) {
-    env->die(env, stack, "[System Error]getsockopt failed: %s.", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]getsockopt() failed:%s.", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -617,23 +617,23 @@ int32_t SPVM__Sys__Socket__setsockopt(SPVM_ENV* env, SPVM_VALUE* stack) {
   void* obj_optval = stack[3].oval;
   char* optval = NULL;
   if (!obj_optval) {
-    return env->die(env, stack, "$optval must be defined.", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "The option value $optval must be defined.", __func__, FILE_NAME, __LINE__);
   }
   optval = (char*)env->get_chars(env, stack, obj_optval);
   int32_t optval_length = env->length(env, stack, obj_optval);
   
   socklen_t optlen = stack[4].ival;
   if (!(optlen >= 0)) {
-    env->die(env, stack, "$optlen must be greater than or equal to 0.", __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "The length stored at index 0 of $optlen_ref must be greater than or equal to 0.", __func__, FILE_NAME, __LINE__);
   }
   if (!(optlen <= optval_length)) {
-    env->die(env, stack, "$optlen must be less than or equal to the length of $optval.", __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "The length stored at index 0 of $optlen_ref must be less than or equal to the length of the option value $optval.", __func__, FILE_NAME, __LINE__);
   }
   
   int32_t status = setsockopt(sockfd, level, optname, optval, optlen);
   
   if (status == -1) {
-    env->die(env, stack, "[System Error]setsockopt failed: %s.", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]setsockopt() failed:%s.", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -644,7 +644,7 @@ int32_t SPVM__Sys__Socket__setsockopt(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__Sys__Socket__socketpair(SPVM_ENV* env, SPVM_VALUE* stack) {
 #if defined(_WIN32)
-  env->die(env, stack, "socketpair is not supported in this system(defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "Sys::Socket#socketpair method is not supported in this system(defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #else
   
@@ -657,21 +657,21 @@ int32_t SPVM__Sys__Socket__socketpair(SPVM_ENV* env, SPVM_VALUE* stack) {
   void* obj_sv = stack[3].oval;
   
   if (!obj_sv) {
-    return env->die(env, stack, "$sv must be defined.", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "The socket pair $sv must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   int32_t* sv = env->get_elems_int(env, stack, obj_sv);
   int32_t sv_length = env->length(env, stack, obj_sv);
   
   if (!(sv_length == 2)) {
-    return env->die(env, stack, "The length of $sv must be equal to 2.", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "The length of the socket pair $sv must be equal to 2.", __func__, FILE_NAME, __LINE__);
   }
   
   int int_sv[2];
   int32_t status = socketpair(domain, type, protocol, int_sv);
   
   if (status == -1) {
-    env->die(env, stack, "[System Error]socketpair failed: %s.", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]socketpair() failed:%s.", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -712,11 +712,11 @@ int32_t SPVM__Sys__Socket__getaddrinfo(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   void* obj_res_array = stack[3].oval;
   if (!obj_res_array) {
-    return env->die(env, stack, "$res_array must be defined.", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "The array $res_ref to store a response must be defined.", __func__, FILE_NAME, __LINE__);
   }
   int32_t res_array_length = env->length(env, stack, obj_res_array);
   if (!(res_array_length == 1)) {
-    return env->die(env, stack, "The length of $res_array must be equal to 1.", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "The length of array $res_ref to store a response must be equal to 1.", __func__, FILE_NAME, __LINE__);
   }
   
   struct addrinfo *res = NULL;
@@ -734,7 +734,7 @@ int32_t SPVM__Sys__Socket__getaddrinfo(SPVM_ENV* env, SPVM_VALUE* stack) {
     SPVM__Sys__Socket__gai_strerror(env, stack);
     void* obj_gai_strerror = stack[0].oval;
     const char* ch_gai_strerror = env->get_chars(env, stack, obj_gai_strerror);
-    env->die(env, stack, "[System Error]getaddrinfo failed: %s.", ch_gai_strerror, __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]getaddrinfo() failed:%s.", ch_gai_strerror, __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -750,7 +750,7 @@ int32_t SPVM__Sys__Socket__getnameinfo(SPVM_ENV* env, SPVM_VALUE* stack) {
   void* obj_sa = stack[0].oval;
   
   if (!obj_sa) {
-    return env->die(env, stack, "$sa must be defined.", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "The socket address $sa must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   const struct sockaddr* sa = env->get_pointer(env, stack, obj_sa);
@@ -782,7 +782,7 @@ int32_t SPVM__Sys__Socket__getnameinfo(SPVM_ENV* env, SPVM_VALUE* stack) {
     SPVM__Sys__Socket__gai_strerror(env, stack);
     void* obj_gai_strerror = stack[0].oval;
     const char* ch_gai_strerror = env->get_chars(env, stack, obj_gai_strerror);
-    env->die(env, stack, "[System Error]getnameinfo failed: %s.", ch_gai_strerror, __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]getnameinfo() failed:%s.", ch_gai_strerror, __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -803,7 +803,7 @@ int32_t SPVM__Sys__Socket__gai_strerror(SPVM_ENV* env, SPVM_VALUE* stack) {
     stack[0].oval = obj_error_string;
   }
   else {
-    env->die(env, stack, "[System Error]gai_strerror failed: %s.", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]gai_strerror() failed:%s.", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -812,7 +812,7 @@ int32_t SPVM__Sys__Socket__gai_strerror(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__Sys__Socket__sockatmark(SPVM_ENV* env, SPVM_VALUE* stack) {
 #if defined(_WIN32)
-    env->die(env, stack, "[Not Supported]sockatmark is not supported in this system(defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "Sys::Socket#sockatmark method is not supported in this system(defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #else
   
@@ -821,7 +821,7 @@ int32_t SPVM__Sys__Socket__sockatmark(SPVM_ENV* env, SPVM_VALUE* stack) {
   int32_t status = sockatmark(sockfd);
   
   if (status == -1) {
-    env->die(env, stack, "[System Error]sockatmark failed: %s.", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]sockatmark() failed:%s.", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
